-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2011, 2014. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosu
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- -------------------------------------------------------------------
--
-- Scriptfile to upgrade database from v7.5 to v8.5.6 for DB2 z/OS
--
----------------------------------------------------------------------
-- Following variables need to be changed for customization before 
-- running this script: 
-- @STOGRP@ = DB2 Storage group name (default is SYSDEFLT)
-- @DB_NAME@ = the database name, eg MONITOR
-- @SCHEMA@ = the schema name, eg MONITOR
--
-- Note: Tablespaces should be created with LOCKSIZE ROW to avoid 
--              deadlocks
--       Tablespaces should be created with CCSID UNICODE for
--       performance reasons and codepage coverage for user input
--
-- Run the script in the DB2 command line processor.
--
-- USAGE:   db2 -tf upgradeSchema750.sql
--
-- -------------------------------------------------------------------

----------------------------------------------CHANGED:  SCHEMA_VERSION
DELETE FROM @SCHEMA@.SCHEMA_VERSION;
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) 
  VALUES( 856, 0 );


-- Begin changes for 8.0

CREATE TABLESPACE WBMON087 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   CCSID UNICODE;   
   
ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
        ADD COLUMN PRIORITY NUMERIC(20);   

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
  ALERT_ID VARCHAR(32) NOT NULL,
  COMMENT_OWNER VARCHAR(32) NOT NULL,
  COMMENT_TIME TIMESTAMP NOT NULL,
  COMMENT_TEXT VARCHAR(4000),
  VERSION_ID SMALLINT NOT NULL ,
  PRIMARY KEY ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
) IN @DB_NAME@.WBMON087;

CREATE UNIQUE INDEX @SCHEMA@.ACT_MGR_CMNT_P 
  ON @SCHEMA@.ACT_ALERT_COMMENTS_T 
  (ALERT_ID, COMMENT_OWNER, COMMENT_TIME) 
  NOT PADDED
  USING STOGROUP @STOGRP@;


ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T
ADD COLUMN STATUS VARCHAR(32);

--D189905 set default value of STATUS to be 'Available', otherwise the alert can not be displayed on widget
UPDATE @SCHEMA@.ACT_MGR_ALERTS_T SET STATUS = 'Available';

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
ADD COLUMN HIDDEN SMALLINT ;

UPDATE @SCHEMA@.META_MONITOR_CONTEXT_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
ADD CONSTRAINT META_MONITOR_CONTEXT_C1 
CHECK (HIDDEN IS NOT NULL);

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T
ADD COLUMN HIDDEN SMALLINT ;

UPDATE @SCHEMA@.META_MONITOR_METRIC_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T 
ADD CONSTRAINT META_MONITOR_METRIC_C1 
CHECK (HIDDEN IS NOT NULL);

ALTER TABLE @SCHEMA@.META_KPI_T
ADD COLUMN HIDDEN SMALLINT;        

UPDATE @SCHEMA@.META_KPI_T 
SET HIDDEN = 0;

ALTER TABLE @SCHEMA@.META_KPI_T 
ADD CONSTRAINT META_KPI_C1 
CHECK (HIDDEN IS NOT NULL);
 
-- Begin changes for 8.5.5.0
-- Event source tables

CREATE TABLESPACE WBMON088 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   CCSID UNICODE;    
CREATE TABLESPACE WBMON089 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   CCSID UNICODE;    
CREATE TABLESPACE WBMON090 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   CCSID UNICODE;    
CREATE TABLESPACE WBMON091 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   CCSID UNICODE;

CREATE LOB TABLESPACE WBMLOB37 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE WBMLOB38 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE WBMLOB39 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;
CREATE LOB TABLESPACE WBMLOB40 IN @DB_NAME@ 
   BUFFERPOOL BP32K
   LOCKSIZE LOB
   USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ES_EVENT_SOURCE_T
(
  SOURCE_ID VARCHAR(256) NOT NULL,
  SOURCE_TYPE VARCHAR(32)         ,
  PRIMARY KEY (SOURCE_ID)
) IN @DB_NAME@.WBMON088;

CREATE UNIQUE INDEX @SCHEMA@.ES_EVENT_SOURCE_P 
  ON @SCHEMA@.ES_EVENT_SOURCE_T ( SOURCE_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ES_BMON_EVENT_SOURCE_T
(
  SOURCE_ID VARCHAR(256) NOT NULL,
  DISPLAY_NAME VARCHAR(512),  
  HOST VARCHAR(128),
  PORT INTEGER,
  AUTH_ALIAS VARCHAR(512),  
  PRIMARY KEY ( SOURCE_ID ),
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
) IN @DB_NAME@.WBMON089;

CREATE UNIQUE INDEX @SCHEMA@.ES_BMON_EVENT_SOURCE_P 
  ON @SCHEMA@.ES_BMON_EVENT_SOURCE_T ( SOURCE_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;
  
CREATE TABLE @SCHEMA@.ES_CEI_EVENT_SOURCE_T
(
  SOURCE_ID VARCHAR(256) NOT NULL,
  DISPLAY_NAME VARCHAR(512),  
  HOST VARCHAR(128),
  PORT INTEGER,
  AUTH_ALIAS VARCHAR(512),  
  CELL VARCHAR(128),
  NODE VARCHAR(128),
  SERVER VARCHAR(128),
  CLUSTER_NAME VARCHAR(128),
  PRIMARY KEY ( SOURCE_ID ) ,
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
) IN @DB_NAME@.WBMON090;

CREATE UNIQUE INDEX @SCHEMA@.ES_CEI_EVENT_SOURCE_P 
  ON @SCHEMA@.ES_CEI_EVENT_SOURCE_T ( SOURCE_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_T
(
  MODEL_ID VARCHAR(128) NOT NULL,
  VERSION DECIMAL(19) NOT NULL,
  EVENT_SOURCE_ID VARCHAR(256) NOT NULL,
  PRIMARY KEY ( MODEL_ID, VERSION, EVENT_SOURCE_ID ),
  FOREIGN KEY ( EVENT_SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ), 
  FOREIGN KEY ( MODEL_ID, VERSION ) REFERENCES @SCHEMA@.META_MODEL_T( MODEL_ID, VERSION ) ON DELETE CASCADE
) IN @DB_NAME@.WBMON091;

CREATE UNIQUE INDEX @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_P 
  ON @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_T 
  ( MODEL_ID, VERSION, EVENT_SOURCE_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

ALTER TABLE @SCHEMA@.META_MODEL_T
ADD COLUMN CURRENT_CONSUMPTION_MODE VARCHAR(128);

ALTER TABLE @SCHEMA@.META_MODEL_T
ADD COLUMN TARGET_CONSUMPTION_MODE VARCHAR(128);

ALTER TABLE @SCHEMA@.META_MODEL_T
ADD COLUMN TRANSPORT_TYPE VARCHAR(128);

ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD COLUMN MODEL_PI BLOB(1000M);
  
ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD COLUMN MIGRATED_MODEL_PI BLOB(1000M);

 -- auxiliary table for LOB column MODEL_PI
CREATE AUX TABLE @SCHEMA@.ATLOB37
   IN @DB_NAME@.WBMLOB37
   STORES @SCHEMA@.META_MODEL_T COLUMN MODEL_PI;
-- auxiliary index for LOB column MODEL_PI
CREATE UNIQUE INDEX @SCHEMA@.ATLOB37I
  ON @SCHEMA@.ATLOB37
  USING STOGROUP @STOGRP@;
  
  -- auxiliary table for LOB column MIGRATED_MODEL_PI
CREATE AUX TABLE @SCHEMA@.ATLOB38
   IN @DB_NAME@.WBMLOB38
   STORES @SCHEMA@.META_MODEL_T COLUMN MIGRATED_MODEL_PI;
-- auxiliary index for LOB column MIGRATED_MODEL_PI
CREATE UNIQUE INDEX @SCHEMA@.ATLOB38I
  ON @SCHEMA@.ATLOB38
  USING STOGROUP @STOGRP@;

ALTER TABLE 
  @SCHEMA@.META_KPI_T
  ADD COLUMN LAST_UPDATED TIMESTAMP;

ALTER TABLE 
  @SCHEMA@.META_KPI_PERSONALIZED_T
  ADD COLUMN HISTORY_VALID_FROM TIMESTAMP;

UPDATE @SCHEMA@.META_MODEL_T SET CURRENT_CONSUMPTION_MODE = 'Inactive';

UPDATE @SCHEMA@.META_MODEL_T SET TRANSPORT_TYPE = 'ModelScopedIncomingEvents' WHERE SUBSTR(CODE_GEN_VERSION,1,3) = '6.2';
UPDATE @SCHEMA@.META_MODEL_T SET TRANSPORT_TYPE = 'ModelScopedIncomingEvents' WHERE SUBSTR(CODE_GEN_VERSION,1,3) = '7.0';
UPDATE @SCHEMA@.META_MODEL_T SET TRANSPORT_TYPE = 'VersionScopedIncomingEvents' WHERE SUBSTR(CODE_GEN_VERSION,1,3) = '7.5';
UPDATE @SCHEMA@.META_MODEL_T SET ABXHOST=NULL,ABXPORT=NULL,ABXUSER_ID=NULL,ABXPASSWORD=NULL;

--Begin Monitor 8.5.6.0 changes
-- Add new table for FGS US 205728
CREATE TABLESPACE WBMON092 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL BP32K 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   CCSID UNICODE;   
  
CREATE TABLE @SCHEMA@.FGS_COGNOS_FILTER_T
(
  USER_ID VARCHAR(128) NOT NULL ,
  MODEL_ID VARCHAR(128) NOT NULL , 
  MCID VARCHAR(128) NOT NULL , 
  SECURITY_PREDICATE  VARCHAR(4000) NOT NULL ,
  PRIMARY KEY ( USER_ID, MODEL_ID, MCID )  
) IN @DB_NAME@.WBMON092;

CREATE UNIQUE INDEX
  @SCHEMA@.FGS_COGNOS_FILTER_P ON
  @SCHEMA@.FGS_COGNOS_FILTER_T
( 
  USER_ID, 
  MODEL_ID, 
  MCID
) 
USING STOGROUP @STOGRP@;

COMMIT;



