-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2011, 2014. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Scriptfile to upgrade database from v7.5 to v8.5.6 for Oracle
--
---------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script: 
-- @SCHEMA@ = the schema owner, eg MONITOR
--
-- Run the script in SQL*Plus.
--
-- USAGE:  sqlplus system/passw0rd@orcl @upgradeSchema750.sql
--
-- ------------------------------------------------------------------------------------

---------------------------------------------------------CHANGED:  SCHEMA_VERSION
DELETE FROM @SCHEMA@.SCHEMA_VERSION;
INSERT INTO @SCHEMA@.SCHEMA_VERSION (
        SCHEMA_VERSION, DATA_MIGRATION) 
        VALUES( 856, 0 );         
--Changes for 8.5.5.0
---------- EVENT SOURCE TABLES

CREATE TABLE @SCHEMA@.ES_EVENT_SOURCE_T
(
  SOURCE_ID                          VARCHAR2(256)       NOT NULL ,
  SOURCE_TYPE                        VARCHAR2(128)                 ,
  PRIMARY KEY ( SOURCE_ID ) USING INDEX TABLESPACE MONIDXTS
) TABLESPACE MONDSTS
  LOGGING;

CREATE TABLE @SCHEMA@.ES_BMON_EVENT_SOURCE_T
(
  SOURCE_ID                          VARCHAR2(256)       NOT NULL ,
  DISPLAY_NAME                       VARCHAR2(512)                ,  
  HOST                               VARCHAR2(128)                ,
  PORT                               NUMBER(10,0)                 ,
  AUTH_ALIAS                         VARCHAR2(512)                ,
  PRIMARY KEY ( SOURCE_ID ) USING INDEX TABLESPACE MONIDXTS       ,
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
) TABLESPACE MONDSTS
  LOGGING;

CREATE TABLE @SCHEMA@.ES_CEI_EVENT_SOURCE_T
(
  SOURCE_ID                          VARCHAR2(256)       NOT NULL ,
  DISPLAY_NAME                       VARCHAR2(512)                ,  
  HOST                               VARCHAR2(128)                ,
  PORT                               NUMBER(10,0)                 ,
  AUTH_ALIAS                         VARCHAR2(512)                ,  
  CELL                               VARCHAR2(256)                ,  
  NODE                               VARCHAR2(256)                ,  
  SERVER                             VARCHAR2(256)                ,  
  CLUSTER_NAME                       VARCHAR2(256)                ,  
  PRIMARY KEY ( SOURCE_ID ) USING INDEX TABLESPACE MONIDXTS       ,
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
) TABLESPACE MONDSTS
  LOGGING;

CREATE TABLE @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_T
(
  MODEL_ID                           VARCHAR2(128)       NOT NULL ,
  VERSION                            NUMBER(20,0)        NOT NULL ,
  EVENT_SOURCE_ID                    VARCHAR2(256)       NOT NULL ,
  PRIMARY KEY ( MODEL_ID, VERSION, EVENT_SOURCE_ID ) USING INDEX TABLESPACE MONIDXTS ,
  FOREIGN KEY ( EVENT_SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ),
  FOREIGN KEY ( MODEL_ID, VERSION ) REFERENCES @SCHEMA@.META_MODEL_T( MODEL_ID, VERSION ) ON DELETE CASCADE
) TABLESPACE MONDSTS
  LOGGING;

ALTER TABLE @SCHEMA@.META_MODEL_T
        ADD (CURRENT_CONSUMPTION_MODE VARCHAR2(128));
ALTER TABLE @SCHEMA@.META_MODEL_T
        ADD (TARGET_CONSUMPTION_MODE VARCHAR2(128));
ALTER TABLE @SCHEMA@.META_MODEL_T
        ADD (TRANSPORT_TYPE VARCHAR2(128));
ALTER TABLE @SCHEMA@.META_MODEL_T
        ADD (MODEL_PI BLOB);   
ALTER TABLE @SCHEMA@.META_MODEL_T
        ADD (MIGRATED_MODEL_PI BLOB);   
ALTER TABLE @SCHEMA@.META_KPI_T 
		ADD (LAST_UPDATED TIMESTAMP );
ALTER TABLE @SCHEMA@.META_KPI_PERSONALIZED_T 
		ADD (HISTORY_VALID_FROM TIMESTAMP );
UPDATE @SCHEMA@.META_MODEL_T SET CURRENT_CONSUMPTION_MODE = 'Inactive';
UPDATE @SCHEMA@.META_MODEL_T SET TRANSPORT_TYPE = 'ModelScopedIncomingEvents' WHERE SUBSTR(CODE_GEN_VERSION,1,3) = '6.2';
UPDATE @SCHEMA@.META_MODEL_T SET TRANSPORT_TYPE = 'ModelScopedIncomingEvents' WHERE SUBSTR(CODE_GEN_VERSION,1,3) = '7.0';
UPDATE @SCHEMA@.META_MODEL_T SET TRANSPORT_TYPE = 'VersionScopedIncomingEvents' WHERE SUBSTR(CODE_GEN_VERSION,1,3) = '7.5';
UPDATE @SCHEMA@.META_MODEL_T SET TRANSPORT_TYPE = 'VersionScopedIncomingEvents' WHERE SUBSTR(CODE_GEN_VERSION,1,3) = '8.0';
UPDATE @SCHEMA@.META_MODEL_T SET ABXHOST=NULL,ABXPORT=NULL,ABXUSER_ID=NULL,ABXPASSWORD=NULL;
--Begin Monitor 8.5.6.0 changes
-- Add new table for FGS US 205728
CREATE TABLE @SCHEMA@.FGS_COGNOS_FILTER_T
(
  USER_ID                            VARCHAR(128)        NOT NULL ,
  MODEL_ID                           VARCHAR(128)        NOT NULL , 
  MCID                               VARCHAR(128)        NOT NULL , 
  SECURITY_PREDICATE                 VARCHAR(4000)       NOT NULL 
) TABLESPACE MONDSTS
  LOGGING;

ALTER TABLE @SCHEMA@.FGS_COGNOS_FILTER_T ADD
(
  PRIMARY KEY ( USER_ID, MODEL_ID, MCID )
  USING INDEX TABLESPACE MONIDXTS
);
COMMIT;
QUIT  