-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2011, 2014.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Scriptfile to upgrade database from v7.5 to v8.5.6 for SQL Server
--
-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @DB_NAME@ = the database name, eg MONITOR
-- @SCHEMA@  = the schema name, eg MONITOR
--
--
-- Run the script in the sqlcmd command line processor
--
-- USAGE:  sqlcmd -U <userid> -P <password> -e -i upgradeSchema750.sql
--
-- ------------------------------------------------------------------------------------
use @DB_NAME@
checkpoint
GO

DELETE FROM @SCHEMA@.SCHEMA_VERSION
GO

INSERT INTO @SCHEMA@.SCHEMA_VERSION (
        SCHEMA_VERSION, DATA_MIGRATION) 
        VALUES( 856, 0 )
GO




-- Changes for 8.0

ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T 
  ADD PRIORITY BIGINT
GO 

CREATE TABLE @SCHEMA@.ACT_ALERT_COMMENTS_T
(
    ALERT_ID                           NVARCHAR(32)                        NOT NULL ,
    COMMENT_OWNER                      NVARCHAR(32)                        NOT NULL ,
    COMMENT_TIME                       DATETIME                           NOT NULL ,
    COMMENT_TEXT                       NVARCHAR(4000)                          NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( ALERT_ID, COMMENT_OWNER, COMMENT_TIME )
)
GO

ALTER TABLE @SCHEMA@.ACT_MGR_ALERTS_T 
  ADD STATUS NVARCHAR(32) NULL
GO 

--D189905 set default value of STATUS to be 'Available', otherwise the alert can not be displayed on widget
UPDATE @SCHEMA@.ACT_MGR_ALERTS_T SET STATUS = 'Available'
GO

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T
  ADD HIDDEN SMALLINT NULL
GO 

UPDATE @SCHEMA@.META_MONITOR_CONTEXT_T SET HIDDEN = 0
GO

ALTER TABLE @SCHEMA@.META_MONITOR_CONTEXT_T 
    ADD CONSTRAINT META_MONITOR_CONTEXT_C1 CHECK (HIDDEN IS NOT NULL)
GO 

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T
  ADD HIDDEN SMALLINT NULL
GO 

UPDATE @SCHEMA@.META_MONITOR_METRIC_T SET HIDDEN = 0
GO

ALTER TABLE @SCHEMA@.META_MONITOR_METRIC_T
    ADD CONSTRAINT META_MONITOR_METRIC_C1 CHECK (HIDDEN IS NOT NULL)
GO  

ALTER TABLE @SCHEMA@.META_KPI_T
  ADD HIDDEN SMALLINT NULL
GO 

UPDATE @SCHEMA@.META_KPI_T SET HIDDEN = 0
GO

ALTER TABLE @SCHEMA@.META_KPI_T
    ADD CONSTRAINT META_KPI_C1 CHECK (HIDDEN IS NOT NULL)
GO    

-- Changes for 8.5.5.0
-- Event source tables

CREATE TABLE @SCHEMA@.ES_EVENT_SOURCE_T
(
  SOURCE_ID                          NVARCHAR(256)                     NOT NULL ,
  SOURCE_TYPE                        NVARCHAR(32)                         NULL ,
  PRIMARY KEY NONCLUSTERED ( SOURCE_ID )
)
GO

CREATE TABLE @SCHEMA@.ES_BMON_EVENT_SOURCE_T
(
  SOURCE_ID                          NVARCHAR(256)                      NOT NULL ,
  DISPLAY_NAME                       NVARCHAR(512)                          NULL ,  
  HOST                               NVARCHAR(128)                          NULL ,
  PORT                               INTEGER                                NULL ,
  AUTH_ALIAS                         NVARCHAR(512)                          NULL ,  
  PRIMARY KEY NONCLUSTERED ( SOURCE_ID ) ,
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
)
GO

CREATE TABLE @SCHEMA@.ES_CEI_EVENT_SOURCE_T
(
  SOURCE_ID                          NVARCHAR(256)                      NOT NULL ,
  DISPLAY_NAME                       NVARCHAR(512)                          NULL ,  
  HOST                               NVARCHAR(128)                          NULL ,
  PORT                               INTEGER                                NULL ,
  AUTH_ALIAS                         NVARCHAR(512)                          NULL ,  
  CELL                        NVARCHAR(512)                          NULL ,
  NODE                        NVARCHAR(512)                          NULL ,
  SERVER                        NVARCHAR(512)                          NULL ,
  CLUSTER_NAME                        NVARCHAR(512)                          NULL ,
  PRIMARY KEY NONCLUSTERED ( SOURCE_ID ) ,
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
)
GO



CREATE TABLE @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_T
(
  MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                             NOT NULL ,
  EVENT_SOURCE_ID                    NVARCHAR(256)                      NOT NULL ,
  PRIMARY KEY NONCLUSTERED ( MODEL_ID, VERSION, EVENT_SOURCE_ID ) ,
  FOREIGN KEY ( EVENT_SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ), 
  FOREIGN KEY ( MODEL_ID, VERSION ) REFERENCES @SCHEMA@.META_MODEL_T( MODEL_ID, VERSION ) ON DELETE CASCADE
)
GO

ALTER TABLE @SCHEMA@.META_MODEL_T
    ADD CURRENT_CONSUMPTION_MODE NVARCHAR(128) NULL
GO 

ALTER TABLE @SCHEMA@.META_MODEL_T
    ADD TARGET_CONSUMPTION_MODE NVARCHAR(128) NULL
GO 

ALTER TABLE @SCHEMA@.META_MODEL_T
    ADD TRANSPORT_TYPE NVARCHAR(128) NULL
GO 

ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD  MODEL_PI VARBINARY(MAX) NULL
GO  

ALTER TABLE @SCHEMA@.META_MODEL_T 
  ADD MIGRATED_MODEL_PI VARBINARY(MAX) NULL
GO  

ALTER TABLE @SCHEMA@.META_KPI_T
  ADD LAST_UPDATED DATETIME NULL
GO 

ALTER TABLE @SCHEMA@.META_KPI_PERSONALIZED_T
  ADD HISTORY_VALID_FROM DATETIME NULL
GO 

UPDATE @SCHEMA@.META_MODEL_T SET CURRENT_CONSUMPTION_MODE = 'Inactive'
GO

UPDATE @SCHEMA@.META_MODEL_T SET TRANSPORT_TYPE = 'ModelScopedIncomingEvents' WHERE SUBSTRING(CODE_GEN_VERSION,1,3) = '6.2'
GO

UPDATE @SCHEMA@.META_MODEL_T SET TRANSPORT_TYPE = 'ModelScopedIncomingEvents' WHERE SUBSTRING(CODE_GEN_VERSION,1,3) = '7.0'
GO

UPDATE @SCHEMA@.META_MODEL_T SET TRANSPORT_TYPE = 'VersionScopedIncomingEvents' WHERE SUBSTRING(CODE_GEN_VERSION,1,3) = '7.5'
GO

UPDATE @SCHEMA@.META_MODEL_T SET ABXHOST=NULL,ABXPORT=NULL,ABXUSER_ID=NULL,ABXPASSWORD=NULL
GO
--Begin Monitor 8.5.6.0 changes
-- Add new table for FGS US 205728
CREATE TABLE @SCHEMA@.FGS_COGNOS_FILTER_T
(
    USER_ID                            NVARCHAR(128)                      NOT NULL ,
    MODEL_ID                           NVARCHAR(128)                      NOT NULL , 
    MCID                               NVARCHAR(128)                      NOT NULL , 
    SECURITY_PREDICATE                 NVARCHAR(4000)                     NOT NULL ,
    PRIMARY KEY ( USER_ID, MODEL_ID, MCID )  
) 
GO